# NaturalAGI

This repository stores artifacts and research results are aimed at Natural AGI:

- simulation software
- documentation

## Documentation

1. [Simulation software](/docs/SIMULATION.md)
2. [Natural AGI description](/docs/README.md)
